==> chromium-browser_34.0.1847.116.orig.tar.xz: chromium-34.0.1847.116/ash/test/shell_test_api.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_TEST_SHELL_TEST_API_H_
#define ASH_TEST_SHELL_TEST_API_H_

#include "base/basictypes.h"

namespace views {
namespace corewm {
class InputMethodEventFilter;
}  // namespace corewm
}  // namespace views

namespace ash {
class AshNativeCursorManager;
class ShelfDelegate;
class ShelfModel;
class Shell;

namespace internal {
class AppListController;
class DragDropController;
class RootWindowLayoutManager;
class ScreenPositionController;
class SystemGestureEventFilter;
class WorkspaceController;
}  // namespace internal

namespace test {

// Accesses private data from a Shell for testing.
class ShellTestApi {
public:
  explicit ShellTestApi(Shell* shell);

  internal::RootWindowLayoutManager* root_window_layout();
  views::corewm::InputMethodEventFilter* input_method_event_filter();
  internal::SystemGestureEventFilter* system_gesture_event_filter();
  internal::WorkspaceController* workspace_controller();
  internal::ScreenPositionController* screen_position_controller();
  AshNativeCursorManager* ash_native_cursor_manager();
  ShelfModel* shelf_model();
  internal::DragDropController* drag_drop_controller();
  internal::AppListController* app_list_controller();

  void DisableOutputConfiguratorAnimation();

  // Set ShelfDelegate.
  void SetShelfDelegate(ShelfDelegate* delegate);

 private:
  Shell* shell_;  // not owned

  DISALLOW_COPY_AND_ASSIGN(ShellTestApi);
};

}  // namespace test
}  // namespace ash

#endif  // ASH_TEST_SHELL_TEST_API_H_

==> chromium-browser_37.0.2062.120.orig.tar.xz: chromium-37.0.2062.120/ash/test/shell_test_api.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_TEST_SHELL_TEST_API_H_
#define ASH_TEST_SHELL_TEST_API_H_

#include "base/basictypes.h"

namespace wm {
class InputMethodEventFilter;
}  // namespace wm

namespace ash {
class AppListController;
class AshNativeCursorManager;
class DragDropController;
class MaximizeModeWindowManager;
class RootWindowLayoutManager;
class ScreenPositionController;
class ShelfDelegate;
class ShelfModel;
class Shell;
class SystemGestureEventFilter;
class WorkspaceController;

namespace test {

// Accesses private data from a Shell for testing.
class ShellTestApi {
public:
  explicit ShellTestApi(Shell* shell);

  RootWindowLayoutManager* root_window_layout();
  ::wm::InputMethodEventFilter* input_method_event_filter();
  SystemGestureEventFilter* system_gesture_event_filter();
  WorkspaceController* workspace_controller();
  ScreenPositionController* screen_position_controller();
  AshNativeCursorManager* ash_native_cursor_manager();
  ShelfModel* shelf_model();
  DragDropController* drag_drop_controller();
  AppListController* app_list_controller();
  MaximizeModeWindowManager* maximize_mode_window_manager();
  void DisableDisplayConfiguratorAnimation();

  // Set ShelfDelegate.
  void SetShelfDelegate(ShelfDelegate* delegate);

 private:
  Shell* shell_;  // not owned

  DISALLOW_COPY_AND_ASSIGN(ShellTestApi);
};

}  // namespace test
}  // namespace ash

#endif  // ASH_TEST_SHELL_TEST_API_H_
